==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Polygon/group__PkgPolygon2Ref.js <==
var group__PkgPolygon2Ref =
[
    [ "Concepts", "group__PkgPolygon2Concepts.html", "group__PkgPolygon2Concepts" ],
    [ "Global Functions", "group__PkgPolygon2Functions.html", "group__PkgPolygon2Functions" ],
    [ "Draw a 2D Polygon", "group__PkgDrawPolygon2.html", "group__PkgDrawPolygon2" ],
    [ "Draw a 2D Polygon with Holes", "group__PkgDrawPolygonWithHoles2.html", "group__PkgDrawPolygonWithHoles2" ],
    [ "General_polygon_with_holes_2", "classCGAL_1_1General__polygon__with__holes__2.html", [
      [ "Polygon_2", "classCGAL_1_1General__polygon__with__holes__2.html#a29434b78a41164bf00d00e789ca72617", null ],
      [ "operator<<", "classCGAL_1_1General__polygon__with__holes__2.html#ac1b7a10f31afdaf9be40b1b983c84154", null ],
      [ "operator>>", "classCGAL_1_1General__polygon__with__holes__2.html#ad9a1dd307a51e4e20a7b8d0bf039fdf0", null ]
    ] ],
    [ "Polygon_2", "classCGAL_1_1Polygon__2.html", [
      [ "Container", "classCGAL_1_1Polygon__2.html#a00194ff40333cdeb46f6237a6786d005", null ],
      [ "Edge_const_circulator", "classCGAL_1_1Polygon__2.html#a58113fae308eed14d63f63f532223338", null ],
      [ "Edge_const_iterator", "classCGAL_1_1Polygon__2.html#ae575d525fb2ad134952c28a57be92076", null ],
      [ "Edges", "classCGAL_1_1Polygon__2.html#aa804b30f88dd77fb24bb46fe3516fe92", null ],
      [ "FT", "classCGAL_1_1Polygon__2.html#a04d87b1de472f3573ab7ee998bd8c122", null ],
      [ "Point_2", "classCGAL_1_1Polygon__2.html#a65df166848e4365d38cfc1cedcb4d6d2", null ],
      [ "Segment_2", "classCGAL_1_1Polygon__2.html#ad34b1ecb838f41fed730be3d60bb43be", null ],
      [ "Vertex_circulator", "classCGAL_1_1Polygon__2.html#a9513789e9a22cdcb6b559db0d2e41e30", null ],
      [ "Vertex_iterator", "classCGAL_1_1Polygon__2.html#abfdae92fbbf75d1076a711498bcfd8c5", null ],
      [ "Vertices", "classCGAL_1_1Polygon__2.html#ac2e88583b05cf397f94464617f3bbd79", null ],
      [ "Polygon_2", "classCGAL_1_1Polygon__2.html#adf079a64918db012108ceff5ac82241d", null ],
      [ "Polygon_2", "classCGAL_1_1Polygon__2.html#a47be845e72c4732e0050d2205dca4d30", null ],
      [ "Polygon_2", "classCGAL_1_1Polygon__2.html#aea3c760778c15670f72f1bef8e3e71dd", null ],
      [ "Polygon_2", "classCGAL_1_1Polygon__2.html#a851a4c55f81d260360f686bfe99fa12c", null ],
      [ "Polygon_2", "classCGAL_1_1Polygon__2.html#a70f472d2a157796924224fd7c7002884", null ],
      [ "area", "classCGAL_1_1Polygon__2.html#ac286f10f18daff172c9c5a2108695ada", null ],
      [ "bbox", "classCGAL_1_1Polygon__2.html#aa22a296ee6535ed78e0424aad4ac5ba7", null ],
      [ "begin", "classCGAL_1_1Polygon__2.html#a3bd945b8d8a32a739281277fea5077ac", null ],
      [ "begin", "classCGAL_1_1Polygon__2.html#a575a8a5d496ae29cc606551b2ed5b142", null ],
      [ "bottom_vertex", "classCGAL_1_1Polygon__2.html#a863872bdbe9f5ac59271bdcb0cf50ab7", null ],
      [ "bounded_side", "classCGAL_1_1Polygon__2.html#aff9f5e227e90bb285c7b3fbd8cb23369", null ],
      [ "clear", "classCGAL_1_1Polygon__2.html#a26f2bd5c5a35112fc6beba29b860f8b4", null ],
      [ "container", "classCGAL_1_1Polygon__2.html#a8de2912f07eed7c5c3e4f1652b89be54", null ],
      [ "container", "classCGAL_1_1Polygon__2.html#ad5084406de13b52098d406027d62ecac", null ],
      [ "edge", "classCGAL_1_1Polygon__2.html#a248711791a392a950984c2c0334646bf", null ],
      [ "edges", "classCGAL_1_1Polygon__2.html#af993aff6fdfd26d72ebc9055bcb2f139", null ],
      [ "edges_begin", "classCGAL_1_1Polygon__2.html#a86f33fca6d164c220c4c3ad8f202996d", null ],
      [ "edges_circulator", "classCGAL_1_1Polygon__2.html#ae2ec375b3f99726295d98fdfea9cc369", null ],
      [ "edges_end", "classCGAL_1_1Polygon__2.html#a3a39a28a975453aa5c2346c2e0fe2043", null ],
      [ "end", "classCGAL_1_1Polygon__2.html#a6b83714b47e8dadbc56d20f0df853746", null ],
      [ "end", "classCGAL_1_1Polygon__2.html#a56f189d789280577e5e1d804446eba71", null ],
      [ "erase", "classCGAL_1_1Polygon__2.html#a2e96120934e83ee73ace7a0e207beafa", null ],
      [ "erase", "classCGAL_1_1Polygon__2.html#af2cfe113e380b038cdfce3fd70a3f585", null ],
      [ "erase", "classCGAL_1_1Polygon__2.html#ae5ab413382acd7a90afaf2b404472295", null ],
      [ "has_on_boundary", "classCGAL_1_1Polygon__2.html#ab4136b501282d309cc72fcf4974d1479", null ],
      [ "has_on_bounded_side", "classCGAL_1_1Polygon__2.html#aed22a0e432f6f3fa503ed1e06ec188f5", null ],
      [ "has_on_negative_side", "classCGAL_1_1Polygon__2.html#ac5b6db40b42ec0e92779183b78de32bd", null ],
      [ "has_on_positive_side", "classCGAL_1_1Polygon__2.html#a31d36abde31f74b5f5f808eaa848d2c6", null ],
      [ "has_on_unbounded_side", "classCGAL_1_1Polygon__2.html#a3f70e9c00e0f1cceccfea9405663e658", null ],
      [ "insert", "classCGAL_1_1Polygon__2.html#a549bfe1f56e4a8f7c4ac3676205e4007", null ],
      [ "insert", "classCGAL_1_1Polygon__2.html#a8ecb44995ea7ae30f0003891dd735129", null ],
      [ "insert", "classCGAL_1_1Polygon__2.html#a244ebe215889feea6f69132e7c11e6df", null ],
      [ "insert", "classCGAL_1_1Polygon__2.html#ad9ecb194da73496c15662c1636a29b6a", null ],
      [ "is_clockwise_oriented", "classCGAL_1_1Polygon__2.html#a97bf2a2897ddb855b1029e47c12f8c30", null ],
      [ "is_collinear_oriented", "classCGAL_1_1Polygon__2.html#ade4b77785a9dbd4c0db071347b34be11", null ],
      [ "is_convex", "classCGAL_1_1Polygon__2.html#a3f647c626553c0cc293b4c1e267b43b0", null ],
      [ "is_counterclockwise_oriented", "classCGAL_1_1Polygon__2.html#a50f72a61b1a3eac123e10a8b6d928635", null ],
      [ "is_empty", "classCGAL_1_1Polygon__2.html#a167bfa9dc447b094cb987e639f7019d3", null ],
      [ "is_simple", "classCGAL_1_1Polygon__2.html#a5b405ab2d80ac04e197e509996e3cdfc", null ],
      [ "left_vertex", "classCGAL_1_1Polygon__2.html#a208b93e1c24e12fb20a414eb6827fed7", null ],
      [ "operator!=", "classCGAL_1_1Polygon__2.html#a7c22179fbdf0f6b8c69ad2b980e8d86b", null ],
      [ "operator==", "classCGAL_1_1Polygon__2.html#a0defc827866d4985ea6f4e6335f8c9a0", null ],
      [ "operator[]", "classCGAL_1_1Polygon__2.html#adf72d9c39820b914aa7895a3e6d2e18f", null ],
      [ "operator[]", "classCGAL_1_1Polygon__2.html#a8d7ec35912146067361f54e1c8e53aeb", null ],
      [ "orientation", "classCGAL_1_1Polygon__2.html#a4ce8b4b8395406243ac16c2a120ffc15", null ],
      [ "oriented_side", "classCGAL_1_1Polygon__2.html#a6385012493b99af603666574557f5089", null ],
      [ "push_back", "classCGAL_1_1Polygon__2.html#a66ff561172016056897409f26f23add1", null ],
      [ "resize", "classCGAL_1_1Polygon__2.html#a8bb2e8c83153c09869f6935534332011", null ],
      [ "reverse_orientation", "classCGAL_1_1Polygon__2.html#ac9bca34769a460a300acdc1415be7ca9", null ],
      [ "right_vertex", "classCGAL_1_1Polygon__2.html#adbf749798f8d552eb93a57141bcb20a2", null ],
      [ "set", "classCGAL_1_1Polygon__2.html#a2a1ce71bfd682cdec898bc59143b1263", null ],
      [ "size", "classCGAL_1_1Polygon__2.html#a52bab6b64430d70d6756f4dda5944bac", null ],
      [ "top_vertex", "classCGAL_1_1Polygon__2.html#af5126a26abc0eb1d3010dfe10cbfa5f9", null ],
      [ "vertex", "classCGAL_1_1Polygon__2.html#ae19b8c39122eb1f231caa261044141f2", null ],
      [ "vertex", "classCGAL_1_1Polygon__2.html#a97adc2530d0a914edbcb8f5167e15149", null ],
      [ "vertices", "classCGAL_1_1Polygon__2.html#ae6429118acb66c4ca823c857a7fecc7b", null ],
      [ "vertices_begin", "classCGAL_1_1Polygon__2.html#a2727b04f3e3748027a1a37fdf8b997ac", null ],
      [ "vertices_circulator", "classCGAL_1_1Polygon__2.html#a17611880d89b1e796d33ec38919ae35f", null ],
      [ "vertices_end", "classCGAL_1_1Polygon__2.html#ac1871b3edc12a06f77c46e9169f3c19c", null ],
      [ "operator<<", "classCGAL_1_1Polygon__2.html#aacf55ebc4ccb144496b1aae6b867ef5e", null ],
      [ "operator>>", "classCGAL_1_1Polygon__2.html#a2ff96b1a99b20d61fb974ffdc0f0e96b", null ],
      [ "transform", "classCGAL_1_1Polygon__2.html#a9c5d3a438fa619b673508d7088df03b2", null ]
    ] ],
    [ "Polygon_with_holes_2", "classCGAL_1_1Polygon__with__holes__2.html", [
      [ "Polygon_with_holes_2", "classCGAL_1_1Polygon__with__holes__2.html#ae3f65197ade5c191b59e68c262850a47", null ],
      [ "Polygon_with_holes_2", "classCGAL_1_1Polygon__with__holes__2.html#abaae2728ec47c41dd1644e9e26985e52", null ],
      [ "Polygon_with_holes_2", "classCGAL_1_1Polygon__with__holes__2.html#ab8911643d595832760cb7717729333e0", null ],
      [ "Polygon_with_holes_2", "classCGAL_1_1Polygon__with__holes__2.html#a1ef9f365926c45582d6579b31b5233dd", null ],
      [ "Polygon_with_holes_2", "classCGAL_1_1Polygon__with__holes__2.html#adc3d686732eefb6ee3768905d0a4d8f9", null ],
      [ "Polygon_with_holes_2", "classCGAL_1_1Polygon__with__holes__2.html#a666897d0b3f166db326abc848805d14f", null ],
      [ "bbox", "classCGAL_1_1Polygon__with__holes__2.html#a0df75ff57fe33d43dc5f42ccc3784177", null ],
      [ "operator<<", "classCGAL_1_1Polygon__with__holes__2.html#aafd0ed8cec7a025ebdf537b61222f0e8", null ],
      [ "operator>>", "classCGAL_1_1Polygon__with__holes__2.html#a4b6117c3559e09dcdfa908746984c9bc", null ]
    ] ]
];

==> CGAL-6.0-doc_html.tar.xz: doc_html/Polygon/group__PkgPolygon2Ref.js <==
var group__PkgPolygon2Ref =
[
    [ "Concepts", "group__PkgPolygon2Concepts.html", "group__PkgPolygon2Concepts" ],
    [ "Global Functions", "group__PkgPolygon2Functions.html", "group__PkgPolygon2Functions" ],
    [ "Draw a 2D Polygon", "group__PkgDrawPolygon2.html", "group__PkgDrawPolygon2" ],
    [ "CGAL::General_polygon_with_holes_2< Polygon_ >", "classCGAL_1_1General__polygon__with__holes__2.html", [
      [ "Polygon_2", "classCGAL_1_1General__polygon__with__holes__2.html#a29434b78a41164bf00d00e789ca72617", null ],
      [ "operator<<", "classCGAL_1_1General__polygon__with__holes__2.html#ac1b7a10f31afdaf9be40b1b983c84154", null ],
      [ "operator>>", "classCGAL_1_1General__polygon__with__holes__2.html#ad9a1dd307a51e4e20a7b8d0bf039fdf0", null ]
    ] ],
    [ "CGAL::Multipolygon_with_holes_2< Kernel, Container >", "classCGAL_1_1Multipolygon__with__holes__2.html", [
      [ "Polygon_2", "classCGAL_1_1Multipolygon__with__holes__2.html#ad4c0f8b6ec0e00514e4ee8df2dfe8377", null ],
      [ "Polygon_with_holes_2", "classCGAL_1_1Multipolygon__with__holes__2.html#a4b36e39c6f7d6421aeb10bd18391ecdc", null ],
      [ "Size", "classCGAL_1_1Multipolygon__with__holes__2.html#abac63d31dfe6a053e95862f97accbd84", null ],
      [ "Multipolygon_with_holes_2", "classCGAL_1_1Multipolygon__with__holes__2.html#a5cd8d17189b68c964f290ee518d6ac08", null ],
      [ "Multipolygon_with_holes_2", "classCGAL_1_1Multipolygon__with__holes__2.html#a8367a3ff7b634e645513ce6341d069e9", null ],
      [ "operator<<", "classCGAL_1_1Multipolygon__with__holes__2.html#af5b0068a1e5377a69063534d54d881f8", null ]
    ] ],
    [ "CGAL::Polygon_2< Traits_P, Container_P >", "classCGAL_1_1Polygon__2.html", [
      [ "Container", "classCGAL_1_1Polygon__2.html#a00194ff40333cdeb46f6237a6786d005", null ],
      [ "Edge_const_circulator", "classCGAL_1_1Polygon__2.html#a58113fae308eed14d63f63f532223338", null ],
      [ "Edge_const_iterator", "classCGAL_1_1Polygon__2.html#ae575d525fb2ad134952c28a57be92076", null ],
      [ "Edges", "classCGAL_1_1Polygon__2.html#aa804b30f88dd77fb24bb46fe3516fe92", null ],
      [ "FT", "classCGAL_1_1Polygon__2.html#a04d87b1de472f3573ab7ee998bd8c122", null ],
      [ "Point_2", "classCGAL_1_1Polygon__2.html#a65df166848e4365d38cfc1cedcb4d6d2", null ],
      [ "Segment_2", "classCGAL_1_1Polygon__2.html#ad34b1ecb838f41fed730be3d60bb43be", null ],
      [ "Vertex_circulator", "classCGAL_1_1Polygon__2.html#a9513789e9a22cdcb6b559db0d2e41e30", null ],
      [ "Vertex_iterator", "classCGAL_1_1Polygon__2.html#abfdae92fbbf75d1076a711498bcfd8c5", null ],
      [ "Vertices", "classCGAL_1_1Polygon__2.html#ac2e88583b05cf397f94464617f3bbd79", null ],
      [ "Polygon_2", "classCGAL_1_1Polygon__2.html#adf079a64918db012108ceff5ac82241d", null ],
      [ "Polygon_2", "classCGAL_1_1Polygon__2.html#a47be845e72c4732e0050d2205dca4d30", null ],
      [ "Polygon_2", "classCGAL_1_1Polygon__2.html#a70f472d2a157796924224fd7c7002884", null ],
      [ "area", "classCGAL_1_1Polygon__2.html#ac286f10f18daff172c9c5a2108695ada", null ],
      [ "bbox", "classCGAL_1_1Polygon__2.html#aa22a296ee6535ed78e0424aad4ac5ba7", null ],
      [ "begin", "classCGAL_1_1Polygon__2.html#a3bd945b8d8a32a739281277fea5077ac", null ],
      [ "begin", "classCGAL_1_1Polygon__2.html#a575a8a5d496ae29cc606551b2ed5b142", null ],
      [ "bottom_vertex", "classCGAL_1_1Polygon__2.html#a863872bdbe9f5ac59271bdcb0cf50ab7", null ],
      [ "bounded_side", "classCGAL_1_1Polygon__2.html#aff9f5e227e90bb285c7b3fbd8cb23369", null ],
      [ "clear", "classCGAL_1_1Polygon__2.html#a26f2bd5c5a35112fc6beba29b860f8b4", null ],
      [ "container", "classCGAL_1_1Polygon__2.html#a45fc45b1717500268a251615d3885af1", null ],
      [ "container", "classCGAL_1_1Polygon__2.html#a68be1865f07debadcc17194b07c2f444", null ],
      [ "edge", "classCGAL_1_1Polygon__2.html#a248711791a392a950984c2c0334646bf", null ],
      [ "edges", "classCGAL_1_1Polygon__2.html#af993aff6fdfd26d72ebc9055bcb2f139", null ],
      [ "edges_begin", "classCGAL_1_1Polygon__2.html#a86f33fca6d164c220c4c3ad8f202996d", null ],
      [ "edges_circulator", "classCGAL_1_1Polygon__2.html#ae2ec375b3f99726295d98fdfea9cc369", null ],
      [ "edges_end", "classCGAL_1_1Polygon__2.html#a3a39a28a975453aa5c2346c2e0fe2043", null ],
      [ "end", "classCGAL_1_1Polygon__2.html#a6b83714b47e8dadbc56d20f0df853746", null ],
      [ "end", "classCGAL_1_1Polygon__2.html#a56f189d789280577e5e1d804446eba71", null ],
      [ "erase", "classCGAL_1_1Polygon__2.html#af2cfe113e380b038cdfce3fd70a3f585", null ],
      [ "erase", "classCGAL_1_1Polygon__2.html#ae5ab413382acd7a90afaf2b404472295", null ],
      [ "erase", "classCGAL_1_1Polygon__2.html#a2e96120934e83ee73ace7a0e207beafa", null ],
      [ "has_on_boundary", "classCGAL_1_1Polygon__2.html#ab4136b501282d309cc72fcf4974d1479", null ],
      [ "has_on_bounded_side", "classCGAL_1_1Polygon__2.html#aed22a0e432f6f3fa503ed1e06ec188f5", null ],
      [ "has_on_negative_side", "classCGAL_1_1Polygon__2.html#ac5b6db40b42ec0e92779183b78de32bd", null ],
      [ "has_on_positive_side", "classCGAL_1_1Polygon__2.html#a31d36abde31f74b5f5f808eaa848d2c6", null ],
      [ "has_on_unbounded_side", "classCGAL_1_1Polygon__2.html#a3f70e9c00e0f1cceccfea9405663e658", null ],
      [ "insert", "classCGAL_1_1Polygon__2.html#a8ecb44995ea7ae30f0003891dd735129", null ],
      [ "insert", "classCGAL_1_1Polygon__2.html#ad9ecb194da73496c15662c1636a29b6a", null ],
      [ "insert", "classCGAL_1_1Polygon__2.html#a549bfe1f56e4a8f7c4ac3676205e4007", null ],
      [ "insert", "classCGAL_1_1Polygon__2.html#a244ebe215889feea6f69132e7c11e6df", null ],
      [ "is_clockwise_oriented", "classCGAL_1_1Polygon__2.html#a97bf2a2897ddb855b1029e47c12f8c30", null ],
      [ "is_collinear_oriented", "classCGAL_1_1Polygon__2.html#ade4b77785a9dbd4c0db071347b34be11", null ],
      [ "is_convex", "classCGAL_1_1Polygon__2.html#a3f647c626553c0cc293b4c1e267b43b0", null ],
      [ "is_counterclockwise_oriented", "classCGAL_1_1Polygon__2.html#a50f72a61b1a3eac123e10a8b6d928635", null ],
      [ "is_empty", "classCGAL_1_1Polygon__2.html#a167bfa9dc447b094cb987e639f7019d3", null ],
      [ "is_simple", "classCGAL_1_1Polygon__2.html#a5b405ab2d80ac04e197e509996e3cdfc", null ],
      [ "left_vertex", "classCGAL_1_1Polygon__2.html#a208b93e1c24e12fb20a414eb6827fed7", null ],
      [ "operator!=", "classCGAL_1_1Polygon__2.html#a7c22179fbdf0f6b8c69ad2b980e8d86b", null ],
      [ "operator==", "classCGAL_1_1Polygon__2.html#a0defc827866d4985ea6f4e6335f8c9a0", null ],
      [ "operator[]", "classCGAL_1_1Polygon__2.html#a185b014fe7aec9ecbe892eb3515eb410", null ],
      [ "operator[]", "classCGAL_1_1Polygon__2.html#ac0e8ed0f68b646be5708603cd92db203", null ],
      [ "orientation", "classCGAL_1_1Polygon__2.html#a4ce8b4b8395406243ac16c2a120ffc15", null ],
      [ "oriented_side", "classCGAL_1_1Polygon__2.html#a6385012493b99af603666574557f5089", null ],
      [ "push_back", "classCGAL_1_1Polygon__2.html#a66ff561172016056897409f26f23add1", null ],
      [ "reserve", "classCGAL_1_1Polygon__2.html#a0e5948396f546f1b194942a026fad543", null ],
      [ "resize", "classCGAL_1_1Polygon__2.html#a8bb2e8c83153c09869f6935534332011", null ],
      [ "reverse_orientation", "classCGAL_1_1Polygon__2.html#ac9bca34769a460a300acdc1415be7ca9", null ],
      [ "right_vertex", "classCGAL_1_1Polygon__2.html#adbf749798f8d552eb93a57141bcb20a2", null ],
      [ "set", "classCGAL_1_1Polygon__2.html#a2a1ce71bfd682cdec898bc59143b1263", null ],
      [ "size", "classCGAL_1_1Polygon__2.html#a52bab6b64430d70d6756f4dda5944bac", null ],
      [ "top_vertex", "classCGAL_1_1Polygon__2.html#af5126a26abc0eb1d3010dfe10cbfa5f9", null ],
      [ "vertex", "classCGAL_1_1Polygon__2.html#ad7dea6599cf1fb1f4336caf2bc1cccb0", null ],
      [ "vertex", "classCGAL_1_1Polygon__2.html#abfcb4e846d9f3163a79efee86d3a417d", null ],
      [ "vertices", "classCGAL_1_1Polygon__2.html#af1de9c9ab04f6a238f95fd1c9336e172", null ],
      [ "vertices_begin", "classCGAL_1_1Polygon__2.html#a2727b04f3e3748027a1a37fdf8b997ac", null ],
      [ "vertices_circulator", "classCGAL_1_1Polygon__2.html#a17611880d89b1e796d33ec38919ae35f", null ],
      [ "vertices_end", "classCGAL_1_1Polygon__2.html#ac1871b3edc12a06f77c46e9169f3c19c", null ],
      [ "operator<<", "classCGAL_1_1Polygon__2.html#aacf55ebc4ccb144496b1aae6b867ef5e", null ],
      [ "operator>>", "classCGAL_1_1Polygon__2.html#a2ff96b1a99b20d61fb974ffdc0f0e96b", null ],
      [ "transform", "classCGAL_1_1Polygon__2.html#a9c5d3a438fa619b673508d7088df03b2", null ]
    ] ],
    [ "CGAL::Polygon_with_holes_2< Kernel, Containter >", "classCGAL_1_1Polygon__with__holes__2.html", [
      [ "Polygon_with_holes_2", "classCGAL_1_1Polygon__with__holes__2.html#a2e072d6e4447033245f4468b4b05dbf6", null ],
      [ "Polygon_with_holes_2", "classCGAL_1_1Polygon__with__holes__2.html#abaae2728ec47c41dd1644e9e26985e52", null ],
      [ "Polygon_with_holes_2", "classCGAL_1_1Polygon__with__holes__2.html#ab8911643d595832760cb7717729333e0", null ],
      [ "Polygon_with_holes_2", "classCGAL_1_1Polygon__with__holes__2.html#a1ef9f365926c45582d6579b31b5233dd", null ],
      [ "Polygon_with_holes_2", "classCGAL_1_1Polygon__with__holes__2.html#adc3d686732eefb6ee3768905d0a4d8f9", null ],
      [ "Polygon_with_holes_2", "classCGAL_1_1Polygon__with__holes__2.html#a666897d0b3f166db326abc848805d14f", null ],
      [ "bbox", "classCGAL_1_1Polygon__with__holes__2.html#a0df75ff57fe33d43dc5f42ccc3784177", null ],
      [ "operator<<", "classCGAL_1_1Polygon__with__holes__2.html#aafd0ed8cec7a025ebdf537b61222f0e8", null ],
      [ "operator>>", "classCGAL_1_1Polygon__with__holes__2.html#a4b6117c3559e09dcdfa908746984c9bc", null ]
    ] ]
];
